#!/usr/bin/env python
#
#   filter-index.py
#   zfilenet
#
#   Copyright (C) 2008 Ross Light
#
#   This file is part of zfilenet.
#
#   zfilenet is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   zfilenet is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with zfilenet.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Index server maintenence script

This removes any stray objects from the index database (i.e. objects without
parents).

usage: filter-index.py database
"""

import sqlite3
import sys

import progtools

__author__ = 'Ross Light'
__date__ = 'June 15, 2008'
__all__ = ['COMMIT_SPAN',
           'main',]

COMMIT_SPAN = 100

@progtools.reportexits
def main(args=None):
    if args is None:
        args = sys.argv[1:]
    if len(args) != 1:
        raise progtools.UsageError()
    server_db = sqlite3.connect(args[0])
    cursor = server_db.cursor()
    # Get root directory
    cursor.execute("SELECT variable_value FROM db_variables "
                   "WHERE variable_key = ?;",
                   ('root_directory',))
    (root_directory_uuid,) = cursor.fetchone()
    # Find objects to delete
    cursor.execute("SELECT indexobj_db_id FROM index_objects "
                   "WHERE indexobj_parent ISNULL "
                   "AND indexobj_uuid != ?;", (root_directory_uuid,))
    db_ids = []
    while True:
        result = cursor.fetchone()
        if result is None:
            break
        db_ids.append(result[0])
    # Delete objects
    for i, db_id in enumerate(db_ids):
        cursor.execute("DELETE FROM index_objects WHERE indexobj_db_id = ?;",
                       (db_id,))
        cursor.execute("DELETE FROM files WHERE indexobj_db_id = ?;",
                       (db_id,))
        cursor.execute("DELETE FROM directories WHERE indexobj_db_id = ?;",
                       (db_id,))
        if i > 0 and i % COMMIT_SPAN:
            server_db.commit()
    server_db.commit()
    cursor.execute("VACUUM;")
    server_db.commit()
    return 0

if __name__ == '__main__':
    sys.exit(main())
