#!/usr/bin/env python
#
#   setup.py
#   zfilenet
#
#   Copyright (C) 2008 Ross Light
#
#   This file is part of zfilenet.
#
#   zfilenet is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   zfilenet is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with zfilenet.  If not, see <http://www.gnu.org/licenses/>.
#

"""
Installation script for zfilenet

If you want to build a source distribution, then you need to check out the
source from Bazaar_ and install the `setuptools_bzr`_ setuptools plugin.  This
is not necessary if you are building *from* source.

.. _Bazaar: http://bazaar-vcs.org/
.. _setuptools_bzr: https://launchpad.net/setuptoolsbzr
"""

# Bootstrap setuptools
from ez_setup import use_setuptools
use_setuptools()

# Imports
from setuptools import setup, find_packages

# File metadata
__author__ = 'Ross Light'
__date__ = 'July 6, 2008'
__docformat__ = 'reStructuredText'

# Setup
setup(
    name="zfn",
    version="0.1.2",
    py_modules=['progtools'],
    packages=find_packages(),
    zip_safe=True,
    entry_points={
        'console_scripts': [
            'zfn-blobserver = zfilenet.blobserver:main',
            'zfn-client = zfilenet.simpleclient:main',
            'zfn-indexserver = zfilenet.indexserver:main',
        ]
    },
    # Dependencies
    # Require nose for testing
    # End-users don't need setuptools_bzr, so we don't have it in the
    # setup script
    setup_requires=[
        'nose',
    ],
    install_requires=[
        'simplejson >= 1.7.4',
        'zope.interface >= 3.3.1',
        'Twisted >= 2.5.0',
        'pybonjour >= 1.1.1',
        'SQLAlchemy >= 0.4.6, < 0.5a1',
    ],
    # Package data
    package_data=
    {
        'zfilenet': ['templates/*.html', 'templates/*.xml', 'static/*'],
    },
    test_suite='nose.collector',
    # Project metadata
    author="Ross Light",
    author_email="rlight2@gmail.com",
    description="The Zero-Configuration File Network",
    long_description="""\
ZFN (the Zero-Configuration File Network) aims to be a standards-compliant,
distributed network system, targeted at home users and small businesses. ZFN
requires little to no initial set-up once installed, and can share files
between computers of any operating system.""",
    license="GPLv3",
    keywords=["network", "file", "zero-configuration", "bonjour", "share",
              "distributed",],
    url="http://launchpad.net/zfilenet",
)
